pysophia documentation
**********************

This package provides Python bindings for `sophia <http://sphia.org/>`_, a ligthweight `DBM-like <http://en.wikipedia.org/wiki/Dbm>`_ database. Available operations on a database are inserting a key-value pair, deleting it, or retrieving a value given its key. It is also possible to traverse the records of a database, in ascending or descending order.

Installation
============

First install libsophia using `this script <https://raw.github.com/doukremt/python-sophia/master/install_lib.sh>`_ (to be run from the source package directory if you have the source distribution, or from `/tmp` or similar). Then download the bindings (preferably from `Github <https://github.com/doukremt/python-sophia>`_), and install them with::

    python setup.py install

If you want to check how the library performs, look at the `benchmarks <http://sphia.org/benchmarks.html>`_ on the website of the author, and run the script ``bench.py`` located in the ``tests`` directory of this package, which will give you an idea of what performance you can expect from the module on your specific hardware.

Contents
========

.. toctree::
   :maxdepth: 2
   
   tutorial
   reference


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

